function []=NIAlgVRP(Problem,Capacity)
%Formulating distance matrix===============================================
xy=[Problem(:,2) Problem(:,3)];
[n m]=size (Problem);
a = meshgrid(1:n); 
d = reshape(sqrt(sum((xy(a,:)-xy(a',:)).^2,2)),n,n);
%==========================================================================
%Nearest Neighbour Algorithm Details
%Step 1 : Begin With [1  1], 1 is Depo
%Step 2 :Examine all outlet that not yet served, there will be feasible outlets,
    %and infeasible outlets
%Step 3 :For feasible outlets, choose the best outlet i.e the outlet that has
    %minimum distance, insert it to the route and position it after the last outlet in that route,
    %for example if outlet no. 6 is the best, then [1 6 1]
%Step 4 :Repeat Step 2 and 3 until there is no more feasible outlet
%Step 5 :If there is no more feasible outlet, then Create New Route [1 1] and Repeat Step 1 to Step 4
%Step 6 :Do All the steps until all outlets are served
 Demand=Problem(:,4);
%==========================================================================
if Capacity<max(Demand)
    fprintf('The Capacity of The Vehicle Is Not Feasible\n')
    return
end
%Nearest Insertion Algorithm===============================================
RouteNow=[1 1]; %This is the beginning of Route Construction
UnservedOutlet=2:length(d);
Routes={[]};
while   length(UnservedOutlet)>0
        FeasibleOutletToInsert=[]; %set consists of outlets that can be inserted to existing route 
        Distance=[];
        for NumberOfOutletNotYetInserted=1:length(UnservedOutlet);
            CandidateToInsert=UnservedOutlet(1,NumberOfOutletNotYetInserted);
            Route=[RouteNow(1:end-1) CandidateToInsert 1];
            [NumberOfVehicles, TotalDistance, RouteSets]=ConstEvalVRP(Problem,Route,Capacity); %VRP Constrain Examination
            if  NumberOfVehicles>1
                FeasibleOutletToInsert=FeasibleOutletToInsert;
                Distance=Distance;
            else
%Sets of feasible outlet to insert
                FeasibleOutletToInsert=[FeasibleOutletToInsert CandidateToInsert];
                Distance=[Distance TotalDistance];
            end
%Information about distances after we examine all feasible outlet
        end
        %Choose an outlet that has minimum distance to insert
        if length(FeasibleOutletToInsert)>=1;
           [ShortestDistance idx]=min(Distance);
           best_FeasibleOutletToInsert=FeasibleOutletToInsert(idx);
           g=find(UnservedOutlet(:)==best_FeasibleOutletToInsert);
           UnservedOutlet(g)=[];
           RouteNow=[RouteNow(1:end-1) best_FeasibleOutletToInsert 1];
        end
%If there is no more feasible outlet, then Create New Route [1 1]
        if  length(FeasibleOutletToInsert)==0 | length(UnservedOutlet)==0;
            RouteFixed=RouteNow;
            Routes{end+1}=[RouteFixed];
            RouteNow=[1 1];
        end
end
NumberOfRoutes=length(Routes);
SetsOfNumberOfOutletsInRoute=[];
for RoutesIndex=1:NumberOfRoutes
    NumberOfOutletsInRoute=length(Routes{1,RoutesIndex});
    SetsOfNumberOfOutletsInRoute=[SetsOfNumberOfOutletsInRoute NumberOfOutletsInRoute];
end
ttt=find(SetsOfNumberOfOutletsInRoute(:)<=2);
Routes(ttt)=[];
n=length(Routes);
for RouteIndex=1:n
    Route_VRP=Routes{1,RouteIndex}
    r=length(Route_VRP);
    jum=0;
    for t=1:r-1,
        subrute=jum+(d(Route_VRP(t),Route_VRP(t+1)));
        jum=subrute;
    end
    DistanceSets(RouteIndex,:)=[jum];
    TotalDistance=sum(DistanceSets);
end
NumberOfRoutes=n
TotalDistance=TotalDistance
img = imread ('map.jpg'); %<==File name of your map
min_x = 0;
max_x = 100;
min_y = 0;
max_y = 100;
x=Problem(:,2);
y=Problem(:,3);
figure
x_min = min_x;
x_max = max_x;
y_min = min_y;
y_max = max_y;
imagesc ([x_min x_max ], [y_min y_max], img);
%Colouring Line 
for tyt=1:n
    hold on
    shortestPath=Routes{1,tyt};
    colour=mod(tyt,6);
    xd=[x(shortestPath)];
    yd=[y(shortestPath)];
    for i=2:length(shortestPath)-1
            text(xd(i),yd(i),['  Outlet ',num2str(shortestPath(i))]);
    end
    text(xd(1),yd(1),['  Depo ']);
    if colour==1
    plot(xd,yd,'-cs','LineWidth',2,'MarkerEdgeColor','k',...
                'MarkerFaceColor','g',...
                'MarkerSize',10)
            plot(x(1),y(1),'MarkerEdgeColor','k',...
                'MarkerFaceColor','k',...
                'MarkerSize',10)
    hold on
    elseif colour==2
    plot(xd,yd,'-rs','LineWidth',2,'MarkerEdgeColor','k',...
                'MarkerFaceColor','r',...
                'MarkerSize',10)
            plot(xd(1),yd(1),'MarkerEdgeColor','k',...
                'MarkerFaceColor','k',...
                'MarkerSize',10)
    hold on 
    elseif colour==3
    plot(xd,yd,'-ys','LineWidth',2,'MarkerEdgeColor','k',...
                'MarkerFaceColor','y',...
                'MarkerSize',10)
            plot(xd(1),yd(1),'MarkerEdgeColor','k',...
                'MarkerFaceColor','k',...
                'MarkerSize',10)
    hold on 
    elseif colour==4
    plot(xd,yd,'-ks','LineWidth',2,'MarkerEdgeColor','k',...
                'MarkerFaceColor','w',...
                'MarkerSize',10)
            plot(xd(1),yd(1),'MarkerEdgeColor','k',...
                'MarkerFaceColor','k',...
                'MarkerSize',10)
    hold on 
    elseif colour==5
    plot(xd,yd,'-bs','LineWidth',2,'MarkerEdgeColor','k',...
                'MarkerFaceColor','b',...
                'MarkerSize',10)
            plot(xd(1),yd(1),'MarkerEdgeColor','k',...
                'MarkerFaceColor','k',...
                'MarkerSize',10)
    hold on 
    elseif colour==0
    plot(xd,yd,'-ms','LineWidth',2,'MarkerEdgeColor','k',...
                'MarkerFaceColor','m',...
                'MarkerSize',10)
            plot(xd(1),yd(1),'MarkerEdgeColor','k',...
                'MarkerFaceColor','k',...
                'MarkerSize',10)
    hold on 
    end
end
title(['Total Distance = ',num2str(TotalDistance),'  | Number of Routes = ',num2str(NumberOfRoutes)]);

